@@ -6,16 +6,16 @@
 #' @usage
 #' dBetaCorrBin(x,n,cov,a,b)
 #'
-#' @param x        vector of binomial random variables
-#' @param n        single value for no of binomial trials
-#' @param cov      single value for covariance
-#' @param a        single value for alpha parameter
-#' @param b        single value for beta parameter
+#' @param x        vector of binomial random variables.
+#' @param n        single value for no of binomial trials.
+#' @param cov      single value for covariance.
+#' @param a        single value for alpha parameter.
+#' @param b        single value for beta parameter.
 #'
 #' @details
 #' The probability function and cumulative function can be constructed and are denoted below
 #'
-#' The cumulative probability function is the summation of probability function values
+#' The cumulative probability function is the summation of probability function values.
 #'
 #' \if{html}{\figure{Capture.png}{options: width="50\%"}}
 #' \if{latex}{\figure{Capture.png}{options: width=11cm}}
@@ -39,22 +39,22 @@
 #' \deqn{Corr_{BetaCorrBin}[x]=\frac{cov}{p(1-p)}}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
 #' The output of \code{dBetaCorrBin} gives a list format consisting
 #'
-#' \code{pdf}           probability function values in vector form
+#' \code{pdf}           probability function values in vector form.
 #'
-#' \code{mean}          mean of Beta-Correlated  Binomial Distribution
+#' \code{mean}          mean of Beta-Correlated  Binomial Distribution.
 #'
-#' \code{var}           variance of Beta-Correlated  Binomial Distribution
+#' \code{var}           variance of Beta-Correlated  Binomial Distribution.
 #'
-#' \code{corr}          correlation of Beta-Correlated Binomial Distribution
+#' \code{corr}          correlation of Beta-Correlated Binomial Distribution.
 #'
-#' \code{mincorr}       minimum correlation value possible
+#' \code{mincorr}       minimum correlation value possible.
 #'
-#' \code{maxcorr}       maximum correlation value possible
+#' \code{maxcorr}       maximum correlation value possible.
 #'
 #' @references
 #' Paul, S.R., 1985. A three-parameter generalization of the binomial distribution. Communications in Statistics
@@ -75,6 +75,7 @@
 #' lines(0:10,dBetaCorrBin(0:10,10,0.001,a[i],b[i])$pdf,col = col[i],lwd=2.85)
 #' points(0:10,dBetaCorrBin(0:10,10,0.001,a[i],b[i])$pdf,col = col[i],pch=16)
 #' }
+#'
 #' dBetaCorrBin(0:10,10,0.001,10,13)$pdf      #extracting the pdf values
 #' dBetaCorrBin(0:10,10,0.001,10,13)$mean     #extracting the mean
 #' dBetaCorrBin(0:10,10,0.001,10,13)$var      #extracting the variance
@@ -93,6 +94,7 @@
 #' lines(0:10,pBetaCorrBin(0:10,10,0.001,a[i],b[i]),col = col[i],lwd=2.85)
 #' points(0:10,pBetaCorrBin(0:10,10,0.001,a[i],b[i]),col = col[i],pch=16)
 #' }
+#'
 #' pBetaCorrBin(0:10,10,0.001,10,13)      #acquiring the cumulative probability values
 #'
 #' @export
@@ -206,16 +208,16 @@ dBetaCorrBin<-function(x,n,cov,a,b)
 #' @usage
 #' pBetaCorrBin(x,n,cov,a,b)
 #'
-#' @param x        vector of binomial random variables
-#' @param n        single value for no of binomial trials
-#' @param cov      single value for covariance
+#' @param x        vector of binomial random variables.
+#' @param n        single value for no of binomial trials.
+#' @param cov      single value for covariance.
 #' @param a        single value for alpha parameter
-#' @param b        single value for beta parameter
+#' @param b        single value for beta parameter.
 #'
 #' @details
 #' The probability function and cumulative function can be constructed and are denoted below
 #'
-#' The cumulative probability function is the summation of probability function values
+#' The cumulative probability function is the summation of probability function values.
 #'
 #' \if{html}{\figure{Capture.png}{options: width="50\%"}}
 #' \if{latex}{\figure{Capture.png}{options: width=11cm}}
@@ -239,18 +241,16 @@ dBetaCorrBin<-function(x,n,cov,a,b)
 #' \deqn{Corr_{BetaCorrBin}[x]=\frac{cov}{p(1-p)}}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
-#'
 #' The output of \code{pBetaCorrBin} gives cumulative probability  values in vector form.
 #'
 #' @references
-#'
 #' Paul, S.R., 1985. A three-parameter generalization of the binomial distribution. Communications in Statistics
 #' - Theory and Methods, 14(6), pp.1497-1506.
 #'
-#' Available at: \url{http://www.tandfonline.com/doi/abs/10.1080/03610928508828990} .
+#' Available at: \url{http://www.tandfonline.com/doi/abs/10.1080/03610928508828990}.
 #'
 #' @examples
 #' #plotting the random variables and probability values
@@ -264,6 +264,7 @@ dBetaCorrBin<-function(x,n,cov,a,b)
 #' lines(0:10,dBetaCorrBin(0:10,10,0.001,a[i],b[i])$pdf,col = col[i],lwd=2.85)
 #' points(0:10,dBetaCorrBin(0:10,10,0.001,a[i],b[i])$pdf,col = col[i],pch=16)
 #' }
+#'
 #' dBetaCorrBin(0:10,10,0.001,10,13)$pdf      #extracting the pdf values
 #' dBetaCorrBin(0:10,10,0.001,10,13)$mean     #extracting the mean
 #' dBetaCorrBin(0:10,10,0.001,10,13)$var      #extracting the variance
@@ -282,6 +283,7 @@ dBetaCorrBin<-function(x,n,cov,a,b)
 #' lines(0:10,pBetaCorrBin(0:10,10,0.001,a[i],b[i]),col = col[i],lwd=2.85)
 #' points(0:10,pBetaCorrBin(0:10,10,0.001,a[i],b[i]),col = col[i],pch=16)
 #' }
+#'
 #' pBetaCorrBin(0:10,10,0.001,10,13)      #acquiring the cumulative probability values
 #'
 #' @export
@@ -307,11 +309,11 @@ pBetaCorrBin<-function(x,n,cov,a,b)
 #' @usage
 #' NegLLBetaCorrBin(x,freq,cov,a,b)
 #'
-#' @param x                 vector of binomial random variables
-#' @param freq              vector of frequencies
-#' @param cov               single value for covariance
-#' @param a                 single value for alpha parameter
-#' @param b                 single value for beta parameter
+#' @param x                 vector of binomial random variables.
+#' @param freq              vector of frequencies.
+#' @param cov               single value for covariance.
+#' @param a                 single value for alpha parameter.
+#' @param b                 single value for beta parameter.
 #'
 #' @details
 #' \deqn{freq \ge 0}
@@ -320,10 +322,10 @@ pBetaCorrBin<-function(x,n,cov,a,b)
 #' \deqn{0 < a,b}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
-#' The output of \code{NegLLBetaCorrBin} will produce a single numeric value
+#' The output of \code{NegLLBetaCorrBin} will produce a single numeric value.
 #'
 #' @references
 #'
@@ -336,6 +338,7 @@ pBetaCorrBin<-function(x,n,cov,a,b)
 #' @examples
 #' No.D.D=0:7         #assigning the random variables
 #' Obs.fre.1=c(47,54,43,40,40,41,39,95)      #assigning the corresponding frequencies
+#'
 #' NegLLBetaCorrBin(No.D.D,Obs.fre.1,0.001,9.03,10)     #acquiring the negative log likelihood value
 #'
 #' @export
@@ -444,17 +447,17 @@ NegLLBetaCorrBin<-function(x,freq,cov,a,b)
 #'
 #' The function will estimate the covariance, alpha and beta parameter values using the maximum log
 #' likelihood method for the Beta-Correlated Binomial distribution when the binomial random
-#' variables and corresponding frequencies are given
+#' variables and corresponding frequencies are given.
 #'
 #' @usage
 #' EstMLEBetaCorrBin(x,freq,cov,a,b)
 #'
 #'
-#' @param x       vector of binomial random variables
-#' @param freq    vector of frequencies
-#' @param cov     single value for covariance
-#' @param a       single value for alpha parameter
-#' @param b       single value for beta parameter
+#' @param x       vector of binomial random variables.
+#' @param freq    vector of frequencies.
+#' @param cov     single value for covariance.
+#' @param a       single value for alpha parameter.
+#' @param b       single value for beta parameter.
 #'
 #' @details
 #' \deqn{x = 0,1,2,...}
@@ -463,14 +466,13 @@ NegLLBetaCorrBin<-function(x,freq,cov,a,b)
 #' \deqn{0 < a,b}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
 #' \code{EstMLEBetaCorrBin} here is used as a input parameter for the \code{mle2} function of \pkg{bbmle} package
 #' therefore output is of class of mle2.
 #'
 #' @references
-#'
 #' Paul, S.R., 1985. A three-parameter generalization of the binomial distribution. Communications in Statistics
 #' - Theory and Methods, 14(6), pp.1497-1506.
 #'
@@ -479,7 +481,6 @@ NegLLBetaCorrBin<-function(x,freq,cov,a,b)
 #' @seealso
 #' \code{\link[bbmle]{mle2}}
 #'
-#'
 #' @examples
 #' No.D.D=0:7               #assigning the random variables
 #' Obs.fre.1=c(47,54,43,40,40,41,39,95)     #assigning the corresponding frequencies
@@ -487,6 +488,7 @@ NegLLBetaCorrBin<-function(x,freq,cov,a,b)
 #' #estimating the parameters using maximum log likelihood value and assigning it
 #' parameters=suppressWarnings(bbmle::mle2(EstMLEBetaCorrBin,start = list(cov=0.0050,a=10,b=10),
 #'                        data = list(x=No.D.D,freq=Obs.fre.1)))
+#'
 #' bbmle::coef(parameters)           #extracting the parameters
 #'
 #' @export
@@ -524,20 +526,19 @@ EstMLEBetaCorrBin<-function(x,freq,cov,a,b)
 #' Fitting the Beta-Correlated Binomial Distribution when binomial
 #' random variable, frequency, covariance, alpha and beta parameters are given
 #'
-#' The function will fit the Beta-Correlated binomial Distribution
+#' The function will fit the Beta-Correlated Binomial Distribution
 #' when random variables, corresponding frequencies, covariance, alpha and beta parameters are given.
 #' It will provide the expected frequencies, chi-squared test statistics value, p value,
 #' and degree of freedom so that it can be seen if this distribution fits the data.
 #'
 #' @usage
-#' fitBetaCorrBin(x,obs.freq,cov,a,b,print)
+#' fitBetaCorrBin(x,obs.freq,cov,a,b)
 #'
-#' @param x                  vector of binomial random variables
-#' @param obs.freq           vector of frequencies
-#' @param cov                single value for covariance
-#' @param a                  single value for alpha parameter
-#' @param b                  single value for beta parameter
-#' @param print              logical value for print or not
+#' @param x                  vector of binomial random variables.
+#' @param obs.freq           vector of frequencies.
+#' @param cov                single value for covariance.
+#' @param a                  single value for alpha parameter.
+#' @param b                  single value for beta parameter.
 #'
 #' @details
 #' \deqn{obs.freq \ge 0}
@@ -546,27 +547,43 @@ EstMLEBetaCorrBin<-function(x,freq,cov,a,b)
 #' \deqn{0 < a,b}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
-#' The output of \code{fitBetaCorrBin} gives a list format consisting
+#' The output of \code{fitBetaCorrBin} gives the class format \code{fitBCB} and \code{fit} consisting a list
 #'
-#' \code{bin.ran.var} binomial random variables
+#' \code{bin.ran.var} binomial random variables.
 #'
-#' \code{obs.freq} corresponding observed frequencies
+#' \code{obs.freq} corresponding observed frequencies.
 #'
-#' \code{exp.freq} corresponding expected frequencies
+#' \code{exp.freq} corresponding expected frequencies.
 #'
-#' \code{statistic} chi-squared test statistics
+#' \code{statistic} chi-squared test statistics.
 #'
-#' \code{df} degree of freedom
+#' \code{df} degree of freedom.
 #'
 #' \code{p.value} probability value by chi-squared test statistic
 #'
-#' \code{corr}    Correlation value
+#' \code{corr}    Correlation value.
+#'
+#' \code{fitBCB} fitted probability values of \code{dBetaCorrBin}.
+#'
+#' \code{NegLL} Negative Log Likelihood value.
+#'
+#' \code{a} estimated shape parameter value a.
+#'
+#' \code{b} estimated shape parameter value b.
+#'
+#' \code{cov} estimated covariance value.
+#'
+#' \code{AIC} AIC value.
+#'
+#' \code{call} the inputs of the function.
+#'
+#' Methods \code{summary}, \code{print}, \code{AIC}, \code{residuals} and \code{fitted}
+#' can be used to extract specific outputs.
 #'
 #' @references
-#'
 #' Paul, S.R., 1985. A three-parameter generalization of the binomial distribution. Communications in Statistics
 #' - Theory and Methods, 14(6), pp.1497-1506.
 #'
@@ -579,15 +596,23 @@ EstMLEBetaCorrBin<-function(x,freq,cov,a,b)
 #' #estimating the parameters using maximum log likelihood value and assigning it
 #' parameters=suppressWarnings(bbmle::mle2(EstMLEBetaCorrBin,start = list(cov=0.0050,a=10,b=10),
 #'            data = list(x=No.D.D,freq=Obs.fre.1)))
+#'
 #' covBetaCorrBin=bbmle::coef(parameters)[1]
 #' aBetaCorrBin=bbmle::coef(parameters)[2]
 #' bBetaCorrBin=bbmle::coef(parameters)[3]
+#'
 #' #fitting when the random variable,frequencies,covariance, a and b are given
-#' fitBetaCorrBin(No.D.D,Obs.fre.1,covBetaCorrBin,aBetaCorrBin,bBetaCorrBin)
-#' #extracting the expected frequencies
-#' fitBetaCorrBin(No.D.D,Obs.fre.1,covBetaCorrBin,aBetaCorrBin,bBetaCorrBin,FALSE)$exp.freq
+#' results<-fitBetaCorrBin(No.D.D,Obs.fre.1,covBetaCorrBin,aBetaCorrBin,bBetaCorrBin)
+#' results
+#'
+#' #extract AIC value
+#' AIC(results)
+#'
+#' #extract fitted values
+#' fitted(results)
+#'
 #' @export
-fitBetaCorrBin<-function(x,obs.freq,cov,a,b,print=T)
+fitBetaCorrBin<-function(x,obs.freq,cov,a,b)
 {
   #checking if inputs consist NA(not assigned)values, infinite values or NAN(not a number)values
   #if so creating an error message as well as stopping the function progress.
@@ -598,8 +623,9 @@ fitBetaCorrBin<-function(x,obs.freq,cov,a,b,print=T)
   }
   else
   {
+    est<-dBetaCorrBin(x,max(x),cov,a,b)
     #for given random variables and parameters calculating the estimated probability values
-    est.prob<-dBetaCorrBin(x,max(x),cov,a,b)$pdf
+    est.prob<-est$pdf
     #using the estimated probability values the expected frequencies are calculated
     exp.freq<-round((sum(obs.freq)*est.prob),2)
     #chi-squared test statistics is calculated with observed frequency and expected frequency
@@ -608,16 +634,7 @@ fitBetaCorrBin<-function(x,obs.freq,cov,a,b,print=T)
     df<-length(x)-4
     #p value of chi-squared test statistic is calculated
     p.value<-1-stats::pchisq(statistic,df)
-    #all the above information is mentioned as a message below
-    #and if the user wishes they can print or not to
-    if(print==TRUE)
-    {
-      cat("\nChi-squared test for Beta-Correlated Binomial Distribution\n\n
-          Observed Frequency : ",obs.freq,"\n
-          expected Frequency : ",exp.freq,"\n
-          X-squared =",round(statistic,4),"df =",df,"  p-value =",round(p.value,4),"\n
-          Correlation  =",dBetaCorrBin(x,max(x),cov,a,b)$corr,"\n")
-    }
+
     #checking if df is less than or equal to zero
     if(df<0 | df==0)
     {
@@ -635,10 +652,55 @@ fitBetaCorrBin<-function(x,obs.freq,cov,a,b,print=T)
     {
       warning("Chi-squared approximation is not suitable because expected frequency approximates to zero")
     }
+    #calculating Negative log likelihood value and AIC
+    NegLL<-NegLLBetaCorrBin(x,obs.freq,cov,a,b)
+    AICvalue<-2*3+NegLL
     #the final output is in a list format containing the calculated values
     final<-list("bin.ran.var"=x,"obs.freq"=obs.freq,"exp.freq"=exp.freq,"statistic"=round(statistic,4),
-                "df"=df,"p.value"=round(p.value,4),"corr"=dBetaCorrBin(x,max(x),cov,a,b)$corr)
+                "df"=df,"p.value"=round(p.value,4),"cov"=cov,"a"=a,"b"=b,"corr"=est$corr,"fitBCB"=est,"NegLL"=NegLL,
+                "AIC"=AICvalue,"call"=match.call())
+    class(final)<-c("fitBCB","fit")
+    return(final)
     }
   }
+
+#' @method fitBetaCorrBin default
+#' @export
+fitBetaCorrBin.default<-function(x,obs.freq,cov,a,b)
+{
+  est<-fitBetaCorrBin(x,obs.freq,cov,a,b)
+  return(est)
+}
+
+#' @method print fitBCB
+#' @export
+print.fitBCB<-function(x,...)
+{
+  cat("Call: \n")
+  print(x$call)
+  cat("\nChi-squared test for Beta-Correlated Binomial Distribution \n\t
+      Observed Frequency : ",x$obs.freq,"\n\t
+      expected Frequency : ",x$exp.freq,"\n\t
+      estimated covariance value:",x$cov,"\n\t
+      estimated a parameter :",x$a," , estimated b parameter :",x$b,"\n\t
+      X-squared :",x$statistic,"  ,df :",x$df,"  ,p-value :",x$p.value,"\n")
+}
+
+#' @method summary fitBCB
+#' @export
+summary.fitBCB<-function(object,...)
+{
+  cat("Call: \n")
+  print(object$call)
+  cat("\nChi-squared test for Beta-Correlated Binomial Distribution \n\t
+      Observed Frequency : ",object$obs.freq,"\n\t
+      expected Frequency : ",object$exp.freq,"\n\t
+      estimated covariance value:",object$cov,"\n\t
+      estimated a parameter :",object$a," , estimated b parameter :",object$b,"\n\t
+      X-squared :",object$statistic,"  ,df :",object$df,"  ,p-value :",object$p.value,"\n\t
+      Negative Loglikehood value :",object$NegLL,"\n\t
+      AIC value :",object$AIC,"\n")
+}
+
 #' @importFrom bbmle mle2
 #' @importFrom stats pchisq
