@@ -6,15 +6,15 @@
 #' @usage
 #' dCOMPBin(x,n,p,v)
 #'
-#' @param x        vector of binomial random variables
-#' @param n        single value for no of binomial trials
-#' @param p        single value for probability of success
-#' @param v        single value for  v
+#' @param x        vector of binomial random variables.
+#' @param n        single value for no of binomial trials.
+#' @param p        single value for probability of success.
+#' @param v        single value for  v.
 #'
 #' @details
 #' The probability function and cumulative function can be constructed and are denoted below
 #'
-#' The cumulative probability function is the summation of probability function values
+#' The cumulative probability function is the summation of probability function values.
 #'
 #' \deqn{P_{COMPBin}(x) = \frac{{n \choose x}^v p^x (1-p)^{n-x}}{\sum_{j=0}^{n} {n \choose j}^v p^j (1-p)^{(n-j)}}}
 #' \deqn{x = 0,1,2,3,...n}
@@ -22,19 +22,17 @@
 #' \deqn{0 < p < 1}
 #' \deqn{-\infty < v < +\infty }
 #'
-#'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
 #' The output of \code{dCOMPBin} gives a list format consisting
 #'
-#' \code{pdf}           probability function values in vector form
+#' \code{pdf}           probability function values in vector form.
 #'
-#' \code{mean}          mean of COM Poisson  Binomial Distribution
-#'
-#' \code{var}           variance of COM Poisson  Binomial Distribution
+#' \code{mean}          mean of COM Poisson  Binomial Distribution.
 #'
+#' \code{var}           variance of COM Poisson  Binomial Distribution.
 #'
 #' @references
 #' Extracted from
@@ -57,6 +55,7 @@
 #' lines(0:10,dCOMPBin(0:10,10,a[i],b[i])$pdf,col = col[i],lwd=2.85)
 #' points(0:10,dCOMPBin(0:10,10,a[i],b[i])$pdf,col = col[i],pch=16)
 #' }
+#'
 #' dCOMPBin(0:10,10,0.58,0.022)$pdf      #extracting the pdf values
 #' dCOMPBin(0:10,10,0.58,0.022)$mean     #extracting the mean
 #' dCOMPBin(0:10,10,0.58,0.022)$var      #extracting the variance
@@ -72,6 +71,7 @@
 #' lines(0:10,pCOMPBin(0:10,10,a[i],b[i]),col = col[i],lwd=2.85)
 #' points(0:10,pCOMPBin(0:10,10,a[i],b[i]),col = col[i],pch=16)
 #' }
+#'
 #' pCOMPBin(0:10,10,0.58,0.022)      #acquiring the cumulative probability values
 #'
 #' @export
@@ -151,15 +151,15 @@ dCOMPBin<-function(x,n,p,v)
 #' @usage
 #' pCOMPBin(x,n,p,v)
 #'
-#' @param x        vector of binomial random variables
-#' @param n        single value for no of binomial trials
-#' @param p        single value for probability of success
-#' @param v        single value for  v
+#' @param x        vector of binomial random variables.
+#' @param n        single value for no of binomial trials.
+#' @param p        single value for probability of success.
+#' @param v        single value for  v.
 #'
 #' @details
 #' The probability function and cumulative function can be constructed and are denoted below
 #'
-#' The cumulative probability function is the summation of probability function values
+#' The cumulative probability function is the summation of probability function values.
 #'
 #' \deqn{P_{COMPBin}(x) = \frac{{n \choose x}^v p^x (1-p)^{n-x}}{\sum_{j=0}^{n} {n \choose j}^v p^j (1-p)^{(n-j)}}}
 #' \deqn{x = 0,1,2,3,...n}
@@ -167,14 +167,12 @@ dCOMPBin<-function(x,n,p,v)
 #' \deqn{0 < p < 1}
 #' \deqn{-\infty < v < +\infty }
 #'
-#'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
 #' The output of \code{pCOMPBin} gives  cumulative probability  values in vector form.
 #'
-#'
 #' @references
 #' Extracted from
 #'
@@ -196,6 +194,7 @@ dCOMPBin<-function(x,n,p,v)
 #' lines(0:10,dCOMPBin(0:10,10,a[i],b[i])$pdf,col = col[i],lwd=2.85)
 #' points(0:10,dCOMPBin(0:10,10,a[i],b[i])$pdf,col = col[i],pch=16)
 #' }
+#'
 #' dCOMPBin(0:10,10,0.58,0.022)$pdf      #extracting the pdf values
 #' dCOMPBin(0:10,10,0.58,0.022)$mean     #extracting the mean
 #' dCOMPBin(0:10,10,0.58,0.022)$var      #extracting the variance
@@ -211,6 +210,7 @@ dCOMPBin<-function(x,n,p,v)
 #' lines(0:10,pCOMPBin(0:10,10,a[i],b[i]),col = col[i],lwd=2.85)
 #' points(0:10,pCOMPBin(0:10,10,a[i],b[i]),col = col[i],pch=16)
 #' }
+#'
 #' pCOMPBin(0:10,10,0.58,0.022)      #acquiring the cumulative probability values
 #'
 #' @export
@@ -236,10 +236,10 @@ pCOMPBin<-function(x,n,p,v)
 #' @usage
 #' NegLLCOMPBin(x,freq,p,v)
 #'
-#' @param x                 vector of binomial random variables
-#' @param freq              vector of frequencies
-#' @param p                 single value for probability of success
-#' @param v                 single value for  v
+#' @param x                 vector of binomial random variables.
+#' @param freq              vector of frequencies.
+#' @param p                 single value for probability of success.
+#' @param v                 single value for  v.
 #'
 #' @details
 #' \deqn{freq \ge 0}
@@ -248,10 +248,10 @@ pCOMPBin<-function(x,n,p,v)
 #' \deqn{-\infty < v < +\infty}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
-#' The output of \code{NegLLCOMPBin} will produce a single numeric value
+#' The output of \code{NegLLCOMPBin} will produce a single numeric value.
 #'
 #' @references
 #' Borges, P., Rodrigues, J., Balakrishnan, N. and Bazan, J., 2014. A COM-Poisson type
@@ -263,6 +263,7 @@ pCOMPBin<-function(x,n,p,v)
 #' @examples
 #' No.D.D=0:7         #assigning the random variables
 #' Obs.fre.1=c(47,54,43,40,40,41,39,95)      #assigning the corresponding frequencies
+#'
 #' NegLLCOMPBin(No.D.D,Obs.fre.1,.5,.03)     #acquiring the negative log likelihood value
 #'
 #' @export
@@ -331,16 +332,15 @@ NegLLCOMPBin<-function(x,freq,p,v)
 #'
 #' The function will estimate the probability of success and v parameter using the maximum log
 #' likelihood method for the COM Poisson Binomial distribution when the binomial random
-#' variables and corresponding frequencies are given
+#' variables and corresponding frequencies are given.
 #'
 #' @usage
 #' EstMLECOMPBin(x,freq,p,v)
 #'
-#'
-#' @param x       vector of binomial random variables
-#' @param freq    vector of frequencies
-#' @param p       single value for probability of success
-#' @param v       single value for v
+#' @param x       vector of binomial random variables.
+#' @param freq    vector of frequencies.
+#' @param p       single value for probability of success.
+#' @param v       single value for v.
 #'
 #' @details
 #' \deqn{x = 0,1,2,...}
@@ -349,7 +349,7 @@ NegLLCOMPBin<-function(x,freq,p,v)
 #' \deqn{-\infty < v < +\infty}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
 #' \code{EstMLECOMPBin} here is used as a input parameter for the \code{mle2} function of \pkg{bbmle} package
@@ -362,7 +362,6 @@ NegLLCOMPBin<-function(x,freq,p,v)
 #'
 #' Available at: \url{http://conteudo.icmc.usp.br/CMS/Arquivos/arquivos_enviados/BIBLIOTECA_113_NSE_90.pdf}
 #'
-#'
 #' @examples
 #' No.D.D=0:7               #assigning the random variables
 #' Obs.fre.1=c(47,54,43,40,40,41,39,95)     #assigning the corresponding frequencies
@@ -370,6 +369,7 @@ NegLLCOMPBin<-function(x,freq,p,v)
 #' #estimating the parameters using maximum log likelihood value and assigning it
 #' parameters=suppressWarnings(bbmle::mle2(EstMLECOMPBin,start = list(p=0.5,v=0.1),
 #'                        data = list(x=No.D.D,freq=Obs.fre.1)))
+#'
 #' bbmle::coef(parameters)           #extracting the parameters
 #'
 #' @export
@@ -394,19 +394,18 @@ EstMLECOMPBin<-function(x,freq,p,v)
 #' Fitting the COM Poisson Binomial Distribution when binomial
 #' random variable, frequency, probability of success and v parameter are given
 #'
-#' The function will fit the COM Poisson binomial Distribution
+#' The function will fit the COM Poisson Binomial Distribution
 #' when random variables, corresponding frequencies, probability of success and v parameter are given.
 #' It will provide the expected frequencies, chi-squared test statistics value, p value,
 #' and degree of freedom so that it can be seen if this distribution fits the data.
 #'
 #' @usage
-#' fitCOMPBin(x,obs.freq,p,v,print)
+#' fitCOMPBin(x,obs.freq,p,v)
 #'
-#' @param x                  vector of binomial random variables
-#' @param obs.freq           vector of frequencies
-#' @param p                  single value for probability of success
-#' @param v                  single value for v
-#' @param print              logical value for print or not
+#' @param x                  vector of binomial random variables.
+#' @param obs.freq           vector of frequencies.
+#' @param p                  single value for probability of success.
+#' @param v                  single value for v.
 #'
 #' @details
 #' \deqn{obs.freq \ge 0}
@@ -415,23 +414,37 @@ EstMLECOMPBin<-function(x,freq,p,v)
 #' \deqn{-\infty < v < +\infty}
 #'
 #' \strong{NOTE} : If input parameters are not in given domain conditions
-#' necessary error messages will be provided to go further
+#' necessary error messages will be provided to go further.
 #'
 #' @return
-#' The output of \code{fitCOMPBin} gives a list format consisting
+#' The output of \code{fitCOMPBin} gives the class format \code{fitCPB} and \code{fit} consisting a list
 #'
-#' \code{bin.ran.var} binomial random variables
+#' \code{bin.ran.var} binomial random variables.
 #'
-#' \code{obs.freq} corresponding observed frequencies
+#' \code{obs.freq} corresponding observed frequencies.
 #'
-#' \code{exp.freq} corresponding expected frequencies
+#' \code{exp.freq} corresponding expected frequencies.
 #'
-#' \code{statistic} chi-squared test statistics
+#' \code{statistic} chi-squared test statistics.
 #'
-#' \code{df} degree of freedom
+#' \code{df} degree of freedom.
 #'
-#' \code{p.value} probability value by chi-squared test statistic
+#' \code{p.value} probability value by chi-squared test statistic.
 #'
+#' \code{fitCPB} fitted probability values of \code{dCOMPBin}.
+#'
+#' \code{NegLL} Negative Log Likelihood value.
+#'
+#' \code{p} estimated probability value.
+#'
+#' \code{v} estimated v parameter value.
+#'
+#' \code{AIC} AIC value.
+#'
+#' \code{call} the inputs of the function.
+#'
+#' Methods \code{summary}, \code{print}, \code{AIC}, \code{residuals} and \code{fitted}
+#' can be used to extract specific outputs.
 #'
 #' @references
 #' Borges, P., Rodrigues, J., Balakrishnan, N. and Bazan, J., 2014. A COM-Poisson type
@@ -440,7 +453,6 @@ EstMLECOMPBin<-function(x,freq,p,v)
 #'
 #' Available at: \url{http://conteudo.icmc.usp.br/CMS/Arquivos/arquivos_enviados/BIBLIOTECA_113_NSE_90.pdf}
 #'
-#'
 #' @examples
 #' No.D.D=0:7                    #assigning the random variables
 #' Obs.fre.1=c(47,54,43,40,40,41,39,95)      #assigning the corresponding frequencies
@@ -448,14 +460,22 @@ EstMLECOMPBin<-function(x,freq,p,v)
 #' #estimating the parameters using maximum log likelihood value and assigning it
 #' parameters=suppressWarnings(bbmle::mle2(EstMLECOMPBin,start = list(p=0.5,v=0.050),
 #'            data = list(x=No.D.D,freq=Obs.fre.1)))
+#'
 #' pCOMPBin=bbmle::coef(parameters)[1]
 #' vCOMPBin=bbmle::coef(parameters)[2]
+#'
 #' #fitting when the random variable,frequencies,probability and v parameter are given
-#' fitCOMPBin(No.D.D,Obs.fre.1,pCOMPBin,vCOMPBin)
-#' #extracting the expected frequencies
-#' fitCOMPBin(No.D.D,Obs.fre.1,pCOMPBin,vCOMPBin,FALSE)$exp.freq
+#' results<-fitCOMPBin(No.D.D,Obs.fre.1,pCOMPBin,vCOMPBin)
+#' results
+#'
+#' #extracting the AIC value
+#' AIC(results)
+#'
+#' #extract fitted values
+#' fitted(results)
+#'
 #' @export
-fitCOMPBin<-function(x,obs.freq,p,v,print=T)
+fitCOMPBin<-function(x,obs.freq,p,v)
 {
   #checking if inputs consist NA(not assigned)values, infinite values or NAN(not a number)values
   #if so creating an error message as well as stopping the function progress.
@@ -466,8 +486,9 @@ fitCOMPBin<-function(x,obs.freq,p,v,print=T)
   }
   else
   {
+    est<-dCOMPBin(x,max(x),p,v)
     #for given random variables and parameters calculating the estimated probability values
-    est.prob<-dCOMPBin(x,max(x),p,v)$pdf
+    est.prob<-est$pdf
     #using the estimated probability values the expected frequencies are calculated
     exp.freq<-round((sum(obs.freq)*est.prob),2)
     #chi-squared test statistics is calculated with observed frequency and expected frequency
@@ -476,15 +497,7 @@ fitCOMPBin<-function(x,obs.freq,p,v,print=T)
     df<-length(x)-3
     #p value of chi-squared test statistic is calculated
     p.value<-1-stats::pchisq(statistic,df)
-    #all the above information is mentioned as a message below
-    #and if the user wishes they can print or not to
-    if(print==TRUE)
-    {
-      cat("\nChi-squared test for COM Poisson Binomial Distribution\n\n
-                 Observed Frequency : ",obs.freq,"\n
-                 expected Frequency : ",exp.freq,"\n
-                 X-squared =",round(statistic,4),"df =",df,"  p-value =",round(p.value,4),"\n")
-    }
+
     #checking if any of the expected frequencies are less than five and greater than zero, if so
     #a warning message is provided in interpreting the results
     if(min(exp.freq)<5 && min(exp.freq) > 0)
@@ -502,8 +515,50 @@ fitCOMPBin<-function(x,obs.freq,p,v,print=T)
     {
       warning("Chi-squared approximation is not suitable because expected frequency approximates to zero")
     }
+    #calculating Negative log likelihood value and AIC
+    NegLL<-NegLLCOMPBin(x,obs.freq,p,v)
+    AICvalue<-2*2+NegLL
     #the final output is in a list format containing the calculated values
     final<-list("bin.ran.var"=x,"obs.freq"=obs.freq,"exp.freq"=exp.freq,"statistic"=round(statistic,4),
-                "df"=df,"p.value"=round(p.value,4))
+                "df"=df,"p.value"=round(p.value,4),"fitCPB"=est,"NegLL"=NegLL,"AIC"=AICvalue,"p"=p,"v"=v,
+                "call"=match.call())
+    class(final)<-c("fitCPB","fit")
+    return(final)
   }
 }
+
+#' @method fitCOMPBin default
+#' @export
+fitCOMPBin.default<-function(x,obs.freq,p,v)
+{
+  est<-fitCOMPBin(x,obs.freq,p,v)
+  return(est)
+}
+
+#' @method print fitCPB
+#' @export
+print.fitCPB<-function(x,...)
+{
+  cat("Call: \n")
+  print(x$call)
+  cat("\nChi-squared test for COM Poisson Binomial Distribution \n\t
+      Observed Frequency : ",x$obs.freq,"\n\t
+      expected Frequency : ",x$exp.freq,"\n\t
+      estimated p value :",x$p," ,estimated v parameter :",x$v,"\n\t
+      X-squared :",x$statistic,"  ,df :",x$df,"  ,p-value :",x$p.value,"\n")
+}
+
+#' @method summary fitCPB
+#' @export
+summary.fitCPB<-function(object,...)
+{
+  cat("Call: \n")
+  print(object$call)
+  cat("\nChi-squared test for COM Poisson Binomial Distribution \n\t
+      Observed Frequency : ",object$obs.freq,"\n\t
+      expected Frequency : ",object$exp.freq,"\n\t
+      estimated p value :",object$p," ,estimated v parameter :",object$v,"\n\t
+      X-squared :",object$statistic,"  ,df :",object$df,"  ,p-value :",object$p.value,"\n\t
+      Negative Loglikehood value :",object$NegLL,"\n\t
+      AIC value :",object$AIC,"\n")
+}
