@@ -230,6 +230,51 @@
 #'
 "Terror_data_ARG"
 
+#' Family Epidemics
+#'
+#' In this investigation, families of the same size, two parents and three children, living in different
+#' circumstances of domestic overcrowding were visited at fortnightly intervals. The date of onset and the clinical
+#' nature of upper respiratory infectious experienced by each member of the family were charted on a time scale
+#' marked off in days. Family epidemics of acute coryza-or common colds-were thus available for analysis.
+#'
+#' By inspection of the epidemic time charts, it was possible to identify new or primary introductions of illness
+#' into the household by the onset of a cold after a lapse of 10 days since the last such case in the same home.
+#' Two such cases occurring on the same or succeeding days were classified as multiple primaries. Thereafter, the
+#' links in the epidemic chain of spread were defined by an interval of one day or more between successive cases
+#' in the same family. These family epidemics could then be described thus 1-2-1, 1-1-1-0, 2-1-0, etc. It must be e
+#' mphasized that although this method of classification is somewhat arbitrary, it was completed before the
+#' corresponding theoretical distributions were worked out and the interval chosen agrees with the distribution
+#' of presumptive incubation periods of the common cold seen in field surveys (e.g. Badger, Dingle, Feller,
+#' Hodges, Jordan, and Rammelkamp, 1953).
+#'
+#' @format A data frame with 6 columns and 5 rows
+#' \describe{
+#' \item{\code{Cases}}{No of Further Cases}
+#' \item{\code{Families}}{No of Families}
+#' \item{\code{Father}}{Father with Status of Introducing Cases}
+#' \item{\code{Mother}}{Mother with Status of Introducing Cases}
+#' \item{\code{SChild}}{School Child with Status of Introducing Cases}
+#' \item{\code{PSChild}}{Pre-School Child with Status of Introducing Cases}
+#' }
+#'
+#' @examples
+#'
+#' Epidemic_Cold$Cases
+#' sum(Epidemic_Cold$SChild)
+#'
+#' @source
+#' Extracted from
+#'
+#' Heasman, M. A. and Reid, D. D. (1961). "Theory and observation in family epidemics of the common cold."
+#' Br. J. pleu. SOC. Med., 15, 12-16.
+#'
+"Epidemic_Cold"
+
+#' @export
+.onAttach<-function(libname,pkgname)
+{
+  packageStartupMessage("Hello, This is Amalan. For more details refer --> https://amalan-constat.github.io/R-fitODBOD/index.html")
+}
 
 #' Binomial Data Extraction from Raw data
 #'
@@ -302,17 +347,16 @@ BODextract<-function(data)
 #' Fitting the Binomial Distribution when binomial random variable, frequency and probability
 #' value are given
 #'
-#' The function will fit the binomial distribution when random variables, corresponding
+#' The function will fit the Binomial distribution when random variables, corresponding
 #' frequencies and probability value are given. It will provide the expected frequencies, chi-squared
 #' test statistics value, p value and degree of freedom  so that it can be
 #' seen if this distribution fits the data.
 #'
-#' @usage fitBin(x,obs.freq,p=0,print=T)
+#' @usage fitBin(x,obs.freq,p=0)
 #'
-#' @param x                  vector of binomial random variables
-#' @param obs.freq           vector of frequencies
-#' @param p                  single value for probability
-#' @param print              logical value for print or not
+#' @param x                  vector of binomial random variables.
+#' @param obs.freq           vector of frequencies.
+#' @param p                  single value for probability.
 #'
 #' @details
 #' \deqn{x = 0,1,2,...}
@@ -323,19 +367,25 @@ BODextract<-function(data)
 #' necessary error messages will be provided to go further.
 #'
 #' @return
-#' The output of \code{fitBin} gives a list format consisting
+#' The output of \code{fitBin} gives the class format \code{fitB} and \code{fit} consisting alist
 #'
-#' \code{bin.ran.var} binomial random variables
+#' \code{bin.ran.var} binomial random variables.
 #'
-#' \code{obs.freq} corresponding observed frequencies
+#' \code{obs.freq} corresponding observed frequencies.
 #'
-#' \code{exp.freq} corresponding expected frequencies
+#' \code{exp.freq} corresponding expected frequencies.
 #'
-#' \code{statistic} chi-squared test statistics value
+#' \code{statistic} chi-squared test statistics value.
 #'
-#' \code{df} degree of freedom
+#' \code{df} degree of freedom.
 #'
-#' \code{p.value} probability value by chi-squared test statistic
+#' \code{p.value} probability value by chi-squared test statistic.
+#'
+#' \code{fitB} fitted probability values of \code{dbinom}.
+#'
+#' \code{phat} estimated probability value.
+#'
+#' \code{call} the inputs of the function.
 #'
 #' @examples
 #' No.D.D=0:7      #assigning the random variables
@@ -344,13 +394,11 @@ BODextract<-function(data)
 #' #fitting when the random variable,frequencies,probability value are given.
 #' fitBin(No.D.D,Obs.fre.1,p=0.7)
 #'
-#' fitBin(No.D.D,Obs.fre.1,p=0.7,FALSE)$exp.freq  #extracting the expected frequencies
-#'
 #' #fitting when the random variable,frequencies are given.
 #' fitBin(No.D.D,Obs.fre.1)
 #'
 #' @export
-fitBin<-function(x,obs.freq,p=0,print=T)
+fitBin<-function(x,obs.freq,p=0)
 {
   #checking if inputs consist NA(not assigned)values, infinite values or NAN(not a number)values if so
   #creating an error message as well as stopping the function progress.
@@ -384,15 +432,7 @@ fitBin<-function(x,obs.freq,p=0,print=T)
         df<-length(x)-2
         #p value of chi-squared test statistic is calculated
         p.value<-1-stats::pchisq(statistic,df)
-        #all the above information is mentioned as a message below
-        #and if the user wishes they can print or not to
-        if(print==TRUE)
-        {
-          cat("\nChi-squared test for Binomial Distribution\n\n
-                Observed Frequency : ",obs.freq,"\n
-                expected Frequency : ",exp.freq,"\n
-                X-squared =",round(statistic,4),"df =",df,"p-value =",round(p.value,4),"\n")
-        }
+
         #checking if df is less than or equal to zero
         if(df<0 | df==0)
         {
@@ -412,7 +452,7 @@ fitBin<-function(x,obs.freq,p=0,print=T)
         }
         #the final output is in a list format containing the calculated values
         final<-list("bin.ran.var"=x,"obs.freq"=obs.freq,"exp.freq"=exp.freq,"statistic"=round(statistic,4),
-                    "df"=df,"p.value"=round(p.value,4))
+                    "df"=df,"p.value"=round(p.value,4),"fitB"=est.prob,"phat"=p.hat,"call"=match.call())
       }
       else
       {
@@ -422,16 +462,7 @@ fitBin<-function(x,obs.freq,p=0,print=T)
         exp.freq<-round((sum(obs.freq)*est.prob),2)
         #applying the chi squared test
         ans<-stats::chisq.test(x=obs.freq,p=est.prob)
-        #all the above information is mentioned as a message below
-        #and if the user wishes they can print or not to
-        if(print==TRUE)
-        {
-          cat("\nChi-squared test for Binomial Distribution\n\n
-              Observed Frequency : ",obs.freq,"\n
-              expected Frequency : ",exp.freq,"\n
-              X-squared =",round(ans$statistic,4),"df =",ans$parameter,
-              "p-value =",round(ans$p.value,4),"\n")
-        }
+
         #checking if any of the expected frequencies are less than five and greater than zero, if so
         #a warning message is provided in interpreting the results
         if(min(exp.freq)<5 && min(exp.freq) > 0)
@@ -447,12 +478,50 @@ fitBin<-function(x,obs.freq,p=0,print=T)
         #the final output is in a list format containing the calculated values
         final<-list("bin.ran.var"=x,"obs.freq"=obs.freq,"exp.freq"=exp.freq,
                     "statistic"=round(ans$statistic,4),"df"=ans$parameter,
-                    "p.value"=round(ans$p.value,4))
+                    "p.value"=round(ans$p.value,4),"fitB"=est.prob,"phat"=p,
+                    "call"=match.call())
       }
+      class(final)<-c("fitB","fit")
+      return(final)
     }
   }
 }
 
+#' @method fitBin default
+#' @export
+fitBin.default<-function(x,obs.freq,p=0)
+{
+  est<-fitBin(x,obs.freq,p=0)
+  return(est)
+}
+
+#' @method print fitB
+#' @export
+print.fitB<-function(x,...)
+{
+  cat("Call: \n")
+  print(x$call)
+  cat("\nChi-squared test for Binomial Distribution \n\t
+      Observed Frequency : ",x$obs.freq,"\n\t
+      expected Frequency : ",x$exp.freq,"\n\t
+      estimated probability value :",x$phat,"\n\t
+      X-squared :",x$statistic,"  ,df :",x$df,"  ,p-value :",x$p.value,"\n")
+}
+
+#' @method summary fitB
+#' @export
+summary.fitB<-function(object,...)
+{
+  cat("Call: \n")
+  print(object$call)
+  cat("\nChi-squared test for Binomial Distribution \n\t
+      Observed Frequency : ",object$obs.freq,"\n\t
+      expected Frequency : ",object$exp.freq,"\n\t
+      estimated probability value :",object$phat," \n\t
+      X-squared :",object$statistic,"  ,df :",object$df,"  ,p-value :",object$p.value,"\n")
+}
+
+
 #' @importFrom stats dbinom
 #' @importFrom stats chisq.test
 #' @importFrom stats pchisq
