@@ -1,14 +1,14 @@
 context("Scenario of un wanted inputs")
 test_that("NA values are avoided",{
-          expect_that(fitBin(0:7,c(47,54,43,40,40,41,39,95),NA,F),
+          expect_that(fitBin(0:7,c(47,54,43,40,40,41,39,95),NA),
           throws_error("NA or Infinite or NAN values in the Input"))
         })
 test_that("Infinite values are avoided",{
-          expect_that(fitBin(0:7,c(47,54,43,40,40,41,39,95),Inf,F),
+          expect_that(fitBin(0:7,c(47,54,43,40,40,41,39,95),Inf),
           throws_error("NA or Infinite or NAN values in the Input"))
         })
 test_that("NAN values are avoided",{
-          expect_that(fitBin(0:7,c(47,54,43,40,40,41,39,95),NaN,F),
+          expect_that(fitBin(0:7,c(47,54,43,40,40,41,39,95),NaN),
           throws_error("NA or Infinite or NAN values in the Input"))
         })
 
